/*
  NGL - C++ cross-platform framework for OpenGL based applications
  Copyright (C) 2000-2003 NGL Team

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*!
\file  nglCPUInfo.h
\brief CPU identification and features detection
*/

#ifndef __nglCPUInfo_h__
#define __nglCPUInfo_h__

#include "ngl.h"


//! CPU identification and features detection
/*!
This class is a holder for static methods which identifies the hosting
architecture (see GetType()), the number of CPUs (see GetCount()) and
the different proprietary extensions.
*/
class nglCPUInfo
{
public:
  /// CPU family
  enum Family
  {
    eUnknown,
    eIA32,
    eIA64,
    ePPC,
    eAlpha,
    eMIPS
  };

  static Family GetFamily();   ///< return the host CPU family
  static uint   GetCount();    ///< return the number of running CPU(s)
  static bool   HasMMX();      ///< return true if MMX extensions are available
  static bool   HasSSE();      ///< return true if SSE extensions are available
  static bool   HasSSE2();     ///< return true if SSE2 extensions are available
  static bool   Has3DNow();    ///< return true if 3DNow extensions are available
  static bool   HasAltivec();  ///< return true if Altivec extensions are available

private:
  static Family mFamily;
  static uint   mCount;
  
  static bool mMMX;
  static bool mSSE;
  static bool mSSE2;
  static bool m3DNow;
  static bool mAltivec;

  nglCPUInfo();
  static void FillCPUInfo();
};

#endif // __nglCPUInfo_h__
