/*
  NGL - C++ cross-platform framework for OpenGL based applications
  Copyright (C) 2000-2003 NGL Team

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*!
\file  nglEvent.h
\brief Event emitter/receiver (NGL internals)
*/

#ifndef __nglEvent_h__
#define __nglEvent_h__

#include "ngl.h"
#include "nglTime.h"


//! Base class for objects which generate events
/*!
This class is for NGL internal use only. It provides no service to the user.
*/
class NGL_API nglEvent
{
#ifdef _UNIX_
public:
  static const uint Read;
  static const uint Write;
  static const uint Error;
  static const uint Idle;

  nglEvent();
  virtual ~nglEvent();

  uint    GetFD()      { return mFD; }
  uint    GetFlags()   { return mFlags; }

  void    CallOnEvent(uint Flags);

protected:
  int     mFD;
  uint    mFlags;

  virtual void OnEvent(uint Flags) = 0;
#endif // _UNIX_
};

#endif // __nglEvent_h__
