/*
  NGL - C++ cross-platform framework for OpenGL based applications
  Copyright (C) 2000-2003 NGL Team

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*!
\file  nglIFile.h
\brief File as input file stream
*/

#ifndef __nglIFile_h__
#define __nglIFile_h__

#include "ngl.h"
#include "nglIStream.h"
#include "nglFile.h"


//! Input file stream
/*!
This input stream is based on the nglFile API, and can be used by all objects
based on generic input streams.
*/
class NGL_API nglIFile : public nglIStream
{
public:
  /** @name Life cycle */
  //@{
  nglIFile(nglFile* pFile);
  /*!<
    \param pFile input file

    Build a nglIFile from an existing nglFile object. The \a pFile object is
    not managed by nglIFile, ie. it won't be destroyed when the stream is
    deleted.
  */
  nglIFile(const nglPath& rPath);
  /*!<
    \param rPath file's path

    See nglFile::nglFile().
  */
  virtual ~nglIFile();
  //@}

  /** @name State/error methods */
  //@{
  nglStreamState GetState() const;
  uint           GetError() const;
  const nglChar* GetErrorStr() const;
  const nglChar* GetErrorStr(uint Error) const;
  //@}

  /** @name Stream navigation */
  //@{
  nglSize GetPos() const;
  nglSize SetPos (nglSize Where, nglStreamWhence Whence = eStreamFromStart);
  nglSize Available (uint WordSize = 1);
  //@}

  /** @name Input methods */
  //@{
  virtual nglSize Read (void* pData, nglSize WordCount, uint WordSize = 1);
  //@}

private:
  nglFile* mpFile;
  bool     mOwnFile;
};

#endif // __nglIFile_h__
