/*
  NGL - C++ cross-platform framework for OpenGL based applications
  Copyright (C) 2000-2003 NGL Team

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*!
\file  nglIMemory.h
\brief Memory buffer as input stream
*/

#ifndef __nglIMemory_h__
#define __nglIMemory_h__

#include "ngl.h"
#include "nglIStream.h"


//! Memory buffer as input stream
/*!
This simple class let you use any memory portion as an input stream.
See also nglOMemory.

FIXME: current implementation does not support endianness selection.
*/
class NGL_API nglIMemory : public nglIStream
{
public:
  /** @name Life cycle */
  //@{
  nglIMemory(const void* pBuffer, nglSize ByteCnt);
  /*!<
    \param pBuffer user buffer
    \param ByteCnt byte count of user buffer (if any)

    Build a nglIMemory from an existing buffer. The buffer is not managed by
    nglIMemory, ie. it won't be freed when the stream is deleted.
  */
  //@}

  /** @name State/error methods */
  //@{
  nglStreamState GetState() const;
  uint           GetError() const;
  const nglChar* GetErrorStr(uint Error) const;
  //@}

  /** @name Stream navigation */
  //@{
  nglSize GetPos() const;
  nglSize SetPos (nglSize Where, nglStreamWhence Whence = eStreamFromStart);
  nglSize Available (uint WordSize = 1);
  //@}

  /** @name Input methods */
  //@{
  virtual nglSize Read (void* pData, nglSize WordCount, uint WordSize = 1);
  //@}

private:
  char*   mpBuffer;
  nglSize mSize;
  nglSize mOffset;
};

#endif // __nglIMemory_h__
