/*
  NGL - C++ cross-platform framework for OpenGL based applications
  Copyright (C) 2000-2003 NGL Team

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*!
\file  nglOMemory.h
\brief Memory buffer as input stream
*/

#ifndef __nglOMemory_h__
#define __nglOMemory_h__

#include "ngl.h"
#include "nglOStream.h"


//! Memory buffer as input stream class
/*!
This simple class let you use memory as an output stream. Memory is
automatically allocated and grown along stream usage.
See also nglIMemory.

FIXME: current implementation does not support endianness selection.
*/
class NGL_API nglOMemory : public nglOStream
{
public:
  /** @name Life cycle */
  //@{
  nglOMemory();
  virtual ~nglOMemory();
  //@}

  /** @name State/error methods */
  //@{
  nglStreamState GetState() const;
  uint           GetError() const;
  const nglChar* GetErrorStr(uint Error) const;
  //@}

  /** @name Stream navigation */
  //@{
  nglSize GetPos() const;
  nglSize SetPos (nglSize Where, nglStreamWhence Whence = eStreamFromStart);
  //@}

  /** @name Buffer access */
  //@{
  const char* GetBufferData() const;  ///< Return buffer data address
  nglSize     GetBufferSize() const;  ///< Return buffer size in bytes. This is always greater or at least equal to GetSize().
  nglSize     GetSize() const;        ///< Return the number of bytes written into the buffer
  //@}

  /** @name Output methods */
  //@{
  virtual nglSize Write (const void* pData, nglSize WordCount, uint WordSize);
  //@}

private:
  char*   mpBuffer;
  nglSize mBufferSize;
  nglSize mSize;
  nglSize mOffset;
  nglSize mChunkSize;
};

#endif // __nglOMemory_h__
