/*
  NGL - C++ cross-platform framework for OpenGL based applications
  Copyright (C) 2000-2003 NGL Team

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*!
\file  nglVSTPlugin.h
\brief Steinberg's VST Plugin class

Abstraction of a VST plugin.
*/

#ifndef __nglVSTPlugin_h__
#define __nglVSTPlugin_h__

#include "ngl.h"
#include "nglPlugin.h"


//! Steinberg's VST Plugin class
/*!
You need to use the NGL_VSTPLUGIN_CREATE() helper macro to properly setup the
instance of a VST plugin. Example :

\code
class MyPlugin : public nglVSTPlugin
{
public:
  // FIXME
};

NGL_VSTPLUGIN_CREATE (MyPlugin)
\endcode
*/
class NGL_API nglVSTPlugin : public nglPlugin
{
public:
  /** @name Life cycle */
  //@{
  nglVSTPlugin();
  virtual ~nglVSTPlugin();
  //@}

private:
#ifdef _CARBON_
  /// There is no support in ngl for carbonized/macho vst plugins at the moment.
#endif // _CARBON_

#ifdef _UNIX_
  /// VSTPLugins do no exists under unix at the moment (well, at least there is no support in ngl for them :).
#endif // _UNIX_
};


#define NGL_VSTPLUGIN_CREATE(UserPluginClass) \
  NGL_PLUGIN_CREATE(UserPluginClass)

#define NGL_VSTPLUGIN_CREATE_EX(UserPluginClass, UserInstance) \
  NGL_PLUGIN_CREATE_EX(UserPluginClass, UserInstance)

#endif // __nglVSTPlugin_h__
