/*
  NGL - C++ cross-platform framework for OpenGL based applications
  Copyright (C) 2000-2003 NGL Team

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*!
\file  ngl_config.h
\brief Compilation-time settings and options

This file holds the settings used by the maintainer for a binary release.
It <i>must not</i> be included directly, use <ngl.h> instead.
*/

#ifndef __ngl_config_h__
#define __ngl_config_h__


/*
 * NGL version
 */

#define NGL_VERSION_MAJOR   0
#define NGL_VERSION_MINOR   7
#define NGL_VERSION_MICRO   10

#define NGL_VERSION_MAKE(major, minor, micro) ((major << 16) | (minor << 8) | micro)

#define NGL_VERSION \
        NGL_VERSION_MAKE(NGL_VERSION_MAJOR, NGL_VERSION_MINOR, NGL_VERSION_MICRO)

#define NGL_VERSION_COMPARE(major, minor, micro) \
       (NGL_VERSION_MAKE(major, minor, micro) - NGL_VERSION)


/*
 * Platform detection
 */

/* MS Windows flavours
*/
#ifdef WIN32
#  ifndef _WIN32_
#    define _WIN32_
#  endif
#  ifdef _DEBUG
#    define _DEBUG_
#  endif
#endif // _WIN32_

/* Unix flavours
*/
#ifdef __linux__
#define _LINUX_
#endif

#ifdef __FreeBSD__
#define _FREEBSD_
#endif

#ifdef __CYGWIN__
#define _CYGWIN_
#endif

#ifdef __APPLE__
  // Make Carbon the default choice when compiling on a Mac, even when using gcc
  #if (!defined(_CARBON_) && !defined(_DARWIN_))
    #define _CARBON_
  #endif
#endif

#ifdef __MWERKS__
  #ifdef macintosh
    #define _CARBON_
  #endif
#endif

#if defined(_LINUX_) || defined(_FREEBSD_) || defined(_CYGWIN_) || defined(_DARWIN_) 
#define _UNIX_
#endif


/*
 * Win32 DLL support and linker settings
 */

#ifdef _WIN32_
  /* Automatically import DLL symbols when :
   * - the user did not explicitely required a static build
   * - AND we are not currently building NGL itself as a DLL
   */
  #if !(defined NGL_STATIC_BUILD) && !(defined NGL_DLL_EXPORTS)
  #define NGL_DLL_IMPORTS
  #endif

  #if (defined NGL_DLL_EXPORTS) || (defined NGL_DLL_IMPORTS)
  #  define _STLP_USE_DECLSPEC 1
  #  define _REENTRANT 1
  #endif

  // Are we compiling NGL as a DLL or just static lib/client program?
  #ifdef NGL_DLL_EXPORTS
  #  define _STLP_DESIGNATED_DLL 1
  #  define __STL_NO_IOSTREAMS 1
  #  define __STL_NO_EXCEPTIONS  1

  // DLL symbol import/export crap
  #  define NGL_API __declspec(dllexport)
  #  define NGL_TPL 
  #endif // NGL_DLL_EXPORTS

  #ifdef NGL_DLL_IMPORTS
  #  define NGL_API __declspec(dllimport)
  #  define NGL_TPL extern 
  #  ifdef _DEBUG
  #    pragma comment( lib , "libngld.lib" )
  #  else
  #    pragma comment( lib , "libngl.lib" )
  #  endif //_DEBUG
  #endif // NGL_DLL_IMPORTS

  #if (defined NGL_STATIC_BUILD)
  #  ifdef _DEBUG
  #    pragma comment( lib , "libnglsd.lib" )
  #  else
  #    pragma comment( lib , "libngls.lib" )
  #  endif //_DEBUG
  #endif //(defined NGL_STATIC_BUILD)

  // Add the needed external libs
  #pragma comment( lib , "opengl32.lib" )
  #pragma comment( lib , "glu32.lib" )
  #pragma comment( lib , "winmm.lib" )
#endif // _WIN32_


/*
 * Unicode support
 */

/*
#ifndef NO_WCHAR
#define USE_WCHAR
#endif
*/

// Unix platforms compile with iconv() as a default
#ifdef _UNIX_
#ifndef NO_ICONV
#define USE_ICONV
#endif
#endif // _UNIX_

// Try to use iconv under Carbon / Darwin too:
#ifdef _CARBON_
#ifndef NO_ATSUI
#define USE_ATSUI
#endif
#endif // _CARBON_

// Win32 platform compile with MLang as a default
#ifdef _WIN32_
#ifndef NO_MLANG
#define USE_MLANG
#endif
#endif // _WIN32_

// Fast float convertion functions work allright on Win32
#ifdef _WIN32_
#define USE_FAST_FLOAT_CONVERSION
#endif // _WIN32_

// X11 support (Unix only)
#ifdef _UNIX_
#ifndef _NOGFX_
  #define _X11_

  // XFree86 VideoMode extension support for nglVideoMode
  #ifndef NO_XF86VIDMODE
  #define USE_XF86VIDMODE
  #endif
#endif // _NOGFX_
#endif // _UNIX_


/*
 * 3rd party libraries
 */

/* PNG support for nglImage, requires libpng (1.x) and zlib (1.1.x)
 */
#ifndef NO_LIBPNG
#define USE_LIBPNG
#endif

/* JPEG support for nglImage, requires libjpeg (6b) and zlib (1.1.x)
 */
#ifndef NO_LIBJPEG
#define USE_LIBJPEG
#endif

/* FreeType support for nglFont, requires FreeType (2.x)
 */
#ifndef NO_FREETYPE
#define USE_FREETYPE
#endif


#endif // __ngl_config_h__
